@@ -9,6 +9,7 @@ import tox
 from tox.interpreters import NoInterpreterInfo
 from tox.session.commands.run.sequential import installpkg, runtestenv
 from tox.venv import (
+    MAXINTERP,
     CreationConfig,
     VirtualEnv,
     getdigest,
@@ -69,6 +70,7 @@ def test_create(mocksession, newconfig):
     assert not venv.path.check()
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
     pcalls = mocksession._pcalls
     assert len(pcalls) >= 1
     args = pcalls[0].args
@@ -134,6 +136,7 @@ def test_create_sitepackages(mocksession, newconfig):
     venv = mocksession.getvenv("site")
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
     pcalls = mocksession._pcalls
     assert len(pcalls) >= 1
     args = pcalls[0].args
@@ -143,6 +146,7 @@ def test_create_sitepackages(mocksession, newconfig):
     venv = mocksession.getvenv("nosite")
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
     pcalls = mocksession._pcalls
     assert len(pcalls) >= 1
     args = pcalls[0].args
@@ -164,6 +168,7 @@ def test_install_deps_wildcard(newmocksession):
     venv = mocksession.getvenv("py123")
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
         pcalls = mocksession._pcalls
         assert len(pcalls) == 1
         distshare = venv.envconfig.config.distshare
@@ -200,6 +205,7 @@ def test_install_deps_indexserver(newmocksession):
     venv = mocksession.getvenv("py123")
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
         pcalls = mocksession._pcalls
         assert len(pcalls) == 1
         pcalls[:] = []
@@ -232,6 +238,7 @@ def test_install_deps_pre(newmocksession):
     venv = mocksession.getvenv("python")
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
     pcalls = mocksession._pcalls
     assert len(pcalls) == 1
     pcalls[:] = []
@@ -293,6 +300,7 @@ def test_install_sdist_extras(newmocksession):
     venv = mocksession.getvenv("python")
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
     pcalls = mocksession._pcalls
     assert len(pcalls) == 1
     pcalls[:] = []
@@ -313,6 +321,7 @@ def test_develop_extras(newmocksession, tmpdir):
     venv = mocksession.getvenv("python")
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
     pcalls = mocksession._pcalls
     assert len(pcalls) == 1
     pcalls[:] = []
@@ -518,6 +527,7 @@ def test_install_python3(newmocksession):
     venv = mocksession.getvenv("py123")
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
         pcalls = mocksession._pcalls
         assert len(pcalls) == 1
         args = pcalls[0].args
@@ -1149,6 +1159,18 @@ def test_tox_testenv_interpret_shebang_long_example(tmpdir):
     assert args == expected + base_args
 
 
+@pytest.mark.skipif("sys.platform == 'win32'", reason="no shebang on Windows")
+def test_tox_testenv_interpret_shebang_skip_truncated(tmpdir):
+    testfile = tmpdir.join("check_shebang_truncation.py")
+    original_args = [str(testfile), "arg1", "arg2", "arg3"]
+
+    # interpreter (too long example)
+    testfile.write("#!" + ("x" * (MAXINTERP + 1)))
+    args = prepend_shebang_interpreter(original_args)
+
+    assert args == original_args
+
+
 @pytest.mark.parametrize("download", [True, False, None])
 def test_create_download(mocksession, newconfig, download):
     config = newconfig(
@@ -1164,6 +1186,7 @@ def test_create_download(mocksession, newconfig, download):
     venv = mocksession.getvenv("env")
     with mocksession.newaction(venv.name, "getenv") as action:
         tox_testenv_create(action=action, venv=venv)
+        venv.just_created = True
     pcalls = mocksession._pcalls
     assert len(pcalls) >= 1
     args = pcalls[0].args
